# libpythonproT
Módulo para exemplificar construção de projetos Python no curso Pytools

Nesse curso é ensinado como contribuir com projetos de código aberto 
Link para o curso [Python Pro] (https://www.python.pro.br/)

[![Updates](https://pyup.io/repos/github/AMBEZERRA/libpythonproT/shield.svg)](https://pyup.io/repos/github/AMBEZERRA/libpythonproT/)

[![Python 3](https://pyup.io/repos/github/AMBEZERRA/libpythonproT/python-3-shield.svg)](https://pyup.io/repos/github/AMBEZERRA/libpythonproT/)

Suportada versão de Python 3

Para instlar:
'''console
py -3 -m venv .venv
.venv\Scripts\activate
pip install -r requirements-dev.txt
'''
Para conferir qualidade de código
'''console
flake8
'''
Tópicos a serem abordados
 1. Git
 2. Virtualenv
 3. Pip
